View source: R/Cal_Cross_Corr.R
| Cal_Cross_Corr | R Documentation |
This function calculates the cross correlation between two time series.
Cal_Cross_Corr(ts1, ts2, max_lag)
ts1 |
a numeric vector of the first time series data. |
ts2 |
a numeric vector of the second time series data. |
max_lag |
maximum lag at which to compute cross-correlation. |
A data frame.
Hossein hassani, Masoud yarmohammadi, Mohammad reza yeganegi and Leila Marvian Mashhad.
data(co2)
data(sunspots)
Cal_Cross_Corr(co2,sunspots,4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.