View source: R/Estimate_Acps.R
| Estimate_Acps | R Documentation |
This function is used to estimate the autocorrelation power spectrum (ACPS) of the data.
Estimate_Acps(ts, method = "periodogram")
ts |
a vector of time series data. |
method |
periodogram method for power spectrum estimation. |
A vector.
Hossein hassani, Masoud yarmohammdi, Mohammad reza yeganegi and Leila Marvian Mashhad.
data(co2)
Estimate_Acps(co2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.