get.ahat: Calculating the Acceleration

View source: R/get.ahat.R

get.ahatR Documentation

Calculating the Acceleration

Description

This function calculates the acceleration for the bias and acceleration corrected intervals

Usage

get.ahat(x)

Arguments

x

vector of resampling estimates to compute the acceleration.

Value

The accelaration estimate.

Author(s)

Hossein hassani, Masoud yarmohammadi, Mohammad reza yeganegi and Leila Marvian Mashhad.

Examples

x = rnorm(100)
get.ahat(x)

ADTSA documentation built on May 29, 2024, 11:48 a.m.

Related to get.ahat in ADTSA...