| get.ahat | R Documentation |
This function calculates the acceleration for the bias and acceleration corrected intervals
get.ahat(x)
x |
vector of resampling estimates to compute the acceleration. |
The accelaration estimate.
Hossein hassani, Masoud yarmohammadi, Mohammad reza yeganegi and Leila Marvian Mashhad.
x = rnorm(100)
get.ahat(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.